# YATODO

<center><a href="https://ja.wikipedia.org/wiki/%E3%83%88%E3%83%89">
  <figure>
    <img src="https://upload.wikimedia.org/wikipedia/commons/thumb/8/85/Adult_male_Northern_Fur_Seal.jpg/250px-Adult_male_Northern_Fur_Seal.jpg" alt="や!トド!" width="200"/>
    <figcaption>や!トド!</figcaption>
  </figure>
</a>
</center>

YATODO (Yet Another TODO) is a placeholder function for code that needs to be implemented. It raises a NotImplementedError with a descriptive message about the call site. It can be inserted anywhere in the code where functionality is yet to be implemented, without basedpyright screaming warnings. You can use it as a placeholder for function bodies, expressions that are not yet decided, or even insert into the middle of an not fully implemented class.
